==> types_boto3_full-1.35.74-py3-none-any.whl: types_boto3_payment_cryptography/type_defs.py <==
"""
Type annotations for payment-cryptography service type definitions.

[Open documentation](https://youtype.github.io/types_boto3_docs/types_boto3_payment_cryptography/type_defs/)

Usage::

    ```python
    from types_boto3_payment_cryptography.type_defs import AliasTypeDef

    data: AliasTypeDef = ...
    ```

Copyright 2024 Vlad Emelianov
"""

import sys
from datetime import datetime
from typing import Dict, List, Mapping, Sequence

from .literals import (
    KeyAlgorithmType,
    KeyCheckValueAlgorithmType,
    KeyClassType,
    KeyExportabilityType,
    KeyMaterialTypeType,
    KeyOriginType,
    KeyStateType,
    KeyUsageType,
    WrappedKeyMaterialFormatType,
    WrappingKeySpecType,
)

if sys.version_info >= (3, 12):
    from typing import Literal, NotRequired, TypedDict
else:
    from typing_extensions import Literal, NotRequired, TypedDict


__all__ = (
    "AliasTypeDef",
    "CreateAliasInputRequestTypeDef",
    "CreateAliasOutputTypeDef",
    "CreateKeyInputRequestTypeDef",
    "CreateKeyOutputTypeDef",
    "DeleteAliasInputRequestTypeDef",
    "DeleteKeyInputRequestTypeDef",
    "DeleteKeyOutputTypeDef",
    "ExportAttributesTypeDef",
    "ExportDukptInitialKeyTypeDef",
    "ExportKeyCryptogramTypeDef",
    "ExportKeyInputRequestTypeDef",
    "ExportKeyMaterialTypeDef",
    "ExportKeyOutputTypeDef",
    "ExportTr31KeyBlockTypeDef",
    "ExportTr34KeyBlockTypeDef",
    "GetAliasInputRequestTypeDef",
    "GetAliasOutputTypeDef",
    "GetKeyInputRequestTypeDef",
    "GetKeyOutputTypeDef",
    "GetParametersForExportInputRequestTypeDef",
    "GetParametersForExportOutputTypeDef",
    "GetParametersForImportInputRequestTypeDef",
    "GetParametersForImportOutputTypeDef",
    "GetPublicKeyCertificateInputRequestTypeDef",
    "GetPublicKeyCertificateOutputTypeDef",
    "ImportKeyCryptogramTypeDef",
    "ImportKeyInputRequestTypeDef",
    "ImportKeyMaterialTypeDef",
    "ImportKeyOutputTypeDef",
    "ImportTr31KeyBlockTypeDef",
    "ImportTr34KeyBlockTypeDef",
    "KeyAttributesTypeDef",
    "KeyBlockHeadersTypeDef",
    "KeyModesOfUseTypeDef",
    "KeySummaryTypeDef",
    "KeyTypeDef",
    "ListAliasesInputListAliasesPaginateTypeDef",
    "ListAliasesInputRequestTypeDef",
    "ListAliasesOutputTypeDef",
    "ListKeysInputListKeysPaginateTypeDef",
    "ListKeysInputRequestTypeDef",
    "ListKeysOutputTypeDef",
    "ListTagsForResourceInputListTagsForResourcePaginateTypeDef",
    "ListTagsForResourceInputRequestTypeDef",
    "ListTagsForResourceOutputTypeDef",
    "PaginatorConfigTypeDef",
    "ResponseMetadataTypeDef",
    "RestoreKeyInputRequestTypeDef",
    "RestoreKeyOutputTypeDef",
    "RootCertificatePublicKeyTypeDef",
    "StartKeyUsageInputRequestTypeDef",
    "StartKeyUsageOutputTypeDef",
    "StopKeyUsageInputRequestTypeDef",
    "StopKeyUsageOutputTypeDef",
    "TagResourceInputRequestTypeDef",
    "TagTypeDef",
    "TrustedCertificatePublicKeyTypeDef",
    "UntagResourceInputRequestTypeDef",
    "UpdateAliasInputRequestTypeDef",
    "UpdateAliasOutputTypeDef",
    "WrappedKeyTypeDef",
)


class AliasTypeDef(TypedDict):
    AliasName: str
    KeyArn: NotRequired[str]


class CreateAliasInputRequestTypeDef(TypedDict):
    AliasName: str
    KeyArn: NotRequired[str]


class ResponseMetadataTypeDef(TypedDict):
    RequestId: str
    HTTPStatusCode: int
    HTTPHeaders: Dict[str, str]
    RetryAttempts: int
    HostId: NotRequired[str]


class TagTypeDef(TypedDict):
    Key: str
    Value: str


class DeleteAliasInputRequestTypeDef(TypedDict):
    AliasName: str


class DeleteKeyInputRequestTypeDef(TypedDict):
    KeyIdentifier: str
    DeleteKeyInDays: NotRequired[int]


class ExportDukptInitialKeyTypeDef(TypedDict):
    KeySerialNumber: str


class ExportKeyCryptogramTypeDef(TypedDict):
    CertificateAuthorityPublicKeyIdentifier: str
    WrappingKeyCertificate: str
    WrappingSpec: NotRequired[WrappingKeySpecType]


class WrappedKeyTypeDef(TypedDict):
    WrappingKeyArn: str
    WrappedKeyMaterialFormat: WrappedKeyMaterialFormatType
    KeyMaterial: str
    KeyCheckValue: NotRequired[str]
    KeyCheckValueAlgorithm: NotRequired[KeyCheckValueAlgorithmType]


class GetAliasInputRequestTypeDef(TypedDict):
    AliasName: str


class GetKeyInputRequestTypeDef(TypedDict):
    KeyIdentifier: str


class GetParametersForExportInputRequestTypeDef(TypedDict):
    KeyMaterialType: KeyMaterialTypeType
    SigningKeyAlgorithm: KeyAlgorithmType


class GetParametersForImportInputRequestTypeDef(TypedDict):
    KeyMaterialType: KeyMaterialTypeType
    WrappingKeyAlgorithm: KeyAlgorithmType


class GetPublicKeyCertificateInputRequestTypeDef(TypedDict):
    KeyIdentifier: str


class ImportTr31KeyBlockTypeDef(TypedDict):
    WrappingKeyIdentifier: str
    WrappedKeyBlock: str


class ImportTr34KeyBlockTypeDef(TypedDict):
    CertificateAuthorityPublicKeyIdentifier: str
    SigningKeyCertificate: str
    ImportToken: str
    WrappedKeyBlock: str
    KeyBlockFormat: Literal["X9_TR34_2012"]
    RandomNonce: NotRequired[str]


class KeyModesOfUseTypeDef(TypedDict):
    Encrypt: NotRequired[bool]
    Decrypt: NotRequired[bool]
    Wrap: NotRequired[bool]
    Unwrap: NotRequired[bool]
    Generate: NotRequired[bool]
    Sign: NotRequired[bool]
    Verify: NotRequired[bool]
    DeriveKey: NotRequired[bool]
    NoRestrictions: NotRequired[bool]


class PaginatorConfigTypeDef(TypedDict):
    MaxItems: NotRequired[int]
    PageSize: NotRequired[int]
    StartingToken: NotRequired[str]


class ListAliasesInputRequestTypeDef(TypedDict):
    KeyArn: NotRequired[str]
    NextToken: NotRequired[str]
    MaxResults: NotRequired[int]


class ListKeysInputRequestTypeDef(TypedDict):
    KeyState: NotRequired[KeyStateType]
    NextToken: NotRequired[str]
    MaxResults: NotRequired[int]


class ListTagsForResourceInputRequestTypeDef(TypedDict):
    ResourceArn: str
    NextToken: NotRequired[str]
    MaxResults: NotRequired[int]


class RestoreKeyInputRequestTypeDef(TypedDict):
    KeyIdentifier: str


class StartKeyUsageInputRequestTypeDef(TypedDict):
    KeyIdentifier: str


class StopKeyUsageInputRequestTypeDef(TypedDict):
    KeyIdentifier: str


class UntagResourceInputRequestTypeDef(TypedDict):
    ResourceArn: str
    TagKeys: Sequence[str]


class UpdateAliasInputRequestTypeDef(TypedDict):
    AliasName: str
    KeyArn: NotRequired[str]


class CreateAliasOutputTypeDef(TypedDict):
    Alias: AliasTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class GetAliasOutputTypeDef(TypedDict):
    Alias: AliasTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class GetParametersForExportOutputTypeDef(TypedDict):
    SigningKeyCertificate: str
    SigningKeyCertificateChain: str
    SigningKeyAlgorithm: KeyAlgorithmType
    ExportToken: str
    ParametersValidUntilTimestamp: datetime
    ResponseMetadata: ResponseMetadataTypeDef


class GetParametersForImportOutputTypeDef(TypedDict):
    WrappingKeyCertificate: str
    WrappingKeyCertificateChain: str
    WrappingKeyAlgorithm: KeyAlgorithmType
    ImportToken: str
    ParametersValidUntilTimestamp: datetime
    ResponseMetadata: ResponseMetadataTypeDef


class GetPublicKeyCertificateOutputTypeDef(TypedDict):
    KeyCertificate: str
    KeyCertificateChain: str
    ResponseMetadata: ResponseMetadataTypeDef


class ListAliasesOutputTypeDef(TypedDict):
    Aliases: List[AliasTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class UpdateAliasOutputTypeDef(TypedDict):
    Alias: AliasTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class ListTagsForResourceOutputTypeDef(TypedDict):
    Tags: List[TagTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class TagResourceInputRequestTypeDef(TypedDict):
    ResourceArn: str
    Tags: Sequence[TagTypeDef]


class ExportAttributesTypeDef(TypedDict):
    ExportDukptInitialKey: NotRequired[ExportDukptInitialKeyTypeDef]
    KeyCheckValueAlgorithm: NotRequired[KeyCheckValueAlgorithmType]


class ExportKeyOutputTypeDef(TypedDict):
    WrappedKey: WrappedKeyTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class KeyAttributesTypeDef(TypedDict):
    KeyUsage: KeyUsageType
    KeyClass: KeyClassType
    KeyAlgorithm: KeyAlgorithmType
    KeyModesOfUse: KeyModesOfUseTypeDef


class KeyBlockHeadersTypeDef(TypedDict):
    KeyModesOfUse: NotRequired[KeyModesOfUseTypeDef]
    KeyExportability: NotRequired[KeyExportabilityType]
    KeyVersion: NotRequired[str]
    OptionalBlocks: NotRequired[Mapping[str, str]]


class ListAliasesInputListAliasesPaginateTypeDef(TypedDict):
    KeyArn: NotRequired[str]
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]


class ListKeysInputListKeysPaginateTypeDef(TypedDict):
    KeyState: NotRequired[KeyStateType]
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]


class ListTagsForResourceInputListTagsForResourcePaginateTypeDef(TypedDict):
    ResourceArn: str
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]


class CreateKeyInputRequestTypeDef(TypedDict):
    KeyAttributes: KeyAttributesTypeDef
    Exportable: bool
    KeyCheckValueAlgorithm: NotRequired[KeyCheckValueAlgorithmType]
    Enabled: NotRequired[bool]
    Tags: NotRequired[Sequence[TagTypeDef]]


class ImportKeyCryptogramTypeDef(TypedDict):
    KeyAttributes: KeyAttributesTypeDef
    Exportable: bool
    WrappedKeyCryptogram: str
    ImportToken: str
    WrappingSpec: NotRequired[WrappingKeySpecType]


class KeySummaryTypeDef(TypedDict):
    KeyArn: str
    KeyState: KeyStateType
    KeyAttributes: KeyAttributesTypeDef
    KeyCheckValue: str
    Exportable: bool
    Enabled: bool


class KeyTypeDef(TypedDict):
    KeyArn: str
    KeyAttributes: KeyAttributesTypeDef
    KeyCheckValue: str
    KeyCheckValueAlgorithm: KeyCheckValueAlgorithmType
    Enabled: bool
    Exportable: bool
    KeyState: KeyStateType
    KeyOrigin: KeyOriginType
    CreateTimestamp: datetime
    UsageStartTimestamp: NotRequired[datetime]
    UsageStopTimestamp: NotRequired[datetime]
    DeletePendingTimestamp: NotRequired[datetime]
    DeleteTimestamp: NotRequired[datetime]


class RootCertificatePublicKeyTypeDef(TypedDict):
    KeyAttributes: KeyAttributesTypeDef
    PublicKeyCertificate: str


class TrustedCertificatePublicKeyTypeDef(TypedDict):
    KeyAttributes: KeyAttributesTypeDef
    PublicKeyCertificate: str
    CertificateAuthorityPublicKeyIdentifier: str


class ExportTr31KeyBlockTypeDef(TypedDict):
    WrappingKeyIdentifier: str
    KeyBlockHeaders: NotRequired[KeyBlockHeadersTypeDef]


class ExportTr34KeyBlockTypeDef(TypedDict):
    CertificateAuthorityPublicKeyIdentifier: str
    WrappingKeyCertificate: str
    ExportToken: str
    KeyBlockFormat: Literal["X9_TR34_2012"]
    RandomNonce: NotRequired[str]
    KeyBlockHeaders: NotRequired[KeyBlockHeadersTypeDef]


class ListKeysOutputTypeDef(TypedDict):
    Keys: List[KeySummaryTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class CreateKeyOutputTypeDef(TypedDict):
    Key: KeyTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class DeleteKeyOutputTypeDef(TypedDict):
    Key: KeyTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class GetKeyOutputTypeDef(TypedDict):
    Key: KeyTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class ImportKeyOutputTypeDef(TypedDict):
    Key: KeyTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class RestoreKeyOutputTypeDef(TypedDict):
    Key: KeyTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class StartKeyUsageOutputTypeDef(TypedDict):
    Key: KeyTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class StopKeyUsageOutputTypeDef(TypedDict):
    Key: KeyTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class ImportKeyMaterialTypeDef(TypedDict):
    RootCertificatePublicKey: NotRequired[RootCertificatePublicKeyTypeDef]
    TrustedCertificatePublicKey: NotRequired[TrustedCertificatePublicKeyTypeDef]
    Tr31KeyBlock: NotRequired[ImportTr31KeyBlockTypeDef]
    Tr34KeyBlock: NotRequired[ImportTr34KeyBlockTypeDef]
    KeyCryptogram: NotRequired[ImportKeyCryptogramTypeDef]


class ExportKeyMaterialTypeDef(TypedDict):
    Tr31KeyBlock: NotRequired[ExportTr31KeyBlockTypeDef]
    Tr34KeyBlock: NotRequired[ExportTr34KeyBlockTypeDef]
    KeyCryptogram: NotRequired[ExportKeyCryptogramTypeDef]


class ImportKeyInputRequestTypeDef(TypedDict):
    KeyMaterial: ImportKeyMaterialTypeDef
    KeyCheckValueAlgorithm: NotRequired[KeyCheckValueAlgorithmType]
    Enabled: NotRequired[bool]
    Tags: NotRequired[Sequence[TagTypeDef]]


class ExportKeyInputRequestTypeDef(TypedDict):
    KeyMaterial: ExportKeyMaterialTypeDef
    ExportKeyIdentifier: str
    ExportAttributes: NotRequired[ExportAttributesTypeDef]

==> types_boto3_full-1.35.91-py3-none-any.whl: types_boto3_payment_cryptography/type_defs.py <==
"""
Type annotations for payment-cryptography service type definitions.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_payment_cryptography/type_defs/)

Usage::

    ```python
    from types_boto3_payment_cryptography.type_defs import AliasTypeDef

    data: AliasTypeDef = ...
    ```

Copyright 2025 Vlad Emelianov
"""

from __future__ import annotations

import sys
from datetime import datetime
from typing import Mapping, Sequence

from .literals import (
    KeyAlgorithmType,
    KeyCheckValueAlgorithmType,
    KeyClassType,
    KeyExportabilityType,
    KeyMaterialTypeType,
    KeyOriginType,
    KeyStateType,
    KeyUsageType,
    WrappedKeyMaterialFormatType,
    WrappingKeySpecType,
)

if sys.version_info >= (3, 12):
    from typing import Literal, NotRequired, TypedDict
else:
    from typing_extensions import Literal, NotRequired, TypedDict


__all__ = (
    "AliasTypeDef",
    "CreateAliasInputRequestTypeDef",
    "CreateAliasOutputTypeDef",
    "CreateKeyInputRequestTypeDef",
    "CreateKeyOutputTypeDef",
    "DeleteAliasInputRequestTypeDef",
    "DeleteKeyInputRequestTypeDef",
    "DeleteKeyOutputTypeDef",
    "ExportAttributesTypeDef",
    "ExportDukptInitialKeyTypeDef",
    "ExportKeyCryptogramTypeDef",
    "ExportKeyInputRequestTypeDef",
    "ExportKeyMaterialTypeDef",
    "ExportKeyOutputTypeDef",
    "ExportTr31KeyBlockTypeDef",
    "ExportTr34KeyBlockTypeDef",
    "GetAliasInputRequestTypeDef",
    "GetAliasOutputTypeDef",
    "GetKeyInputRequestTypeDef",
    "GetKeyOutputTypeDef",
    "GetParametersForExportInputRequestTypeDef",
    "GetParametersForExportOutputTypeDef",
    "GetParametersForImportInputRequestTypeDef",
    "GetParametersForImportOutputTypeDef",
    "GetPublicKeyCertificateInputRequestTypeDef",
    "GetPublicKeyCertificateOutputTypeDef",
    "ImportKeyCryptogramTypeDef",
    "ImportKeyInputRequestTypeDef",
    "ImportKeyMaterialTypeDef",
    "ImportKeyOutputTypeDef",
    "ImportTr31KeyBlockTypeDef",
    "ImportTr34KeyBlockTypeDef",
    "KeyAttributesTypeDef",
    "KeyBlockHeadersTypeDef",
    "KeyModesOfUseTypeDef",
    "KeySummaryTypeDef",
    "KeyTypeDef",
    "ListAliasesInputPaginateTypeDef",
    "ListAliasesInputRequestTypeDef",
    "ListAliasesOutputTypeDef",
    "ListKeysInputPaginateTypeDef",
    "ListKeysInputRequestTypeDef",
    "ListKeysOutputTypeDef",
    "ListTagsForResourceInputPaginateTypeDef",
    "ListTagsForResourceInputRequestTypeDef",
    "ListTagsForResourceOutputTypeDef",
    "PaginatorConfigTypeDef",
    "ResponseMetadataTypeDef",
    "RestoreKeyInputRequestTypeDef",
    "RestoreKeyOutputTypeDef",
    "RootCertificatePublicKeyTypeDef",
    "StartKeyUsageInputRequestTypeDef",
    "StartKeyUsageOutputTypeDef",
    "StopKeyUsageInputRequestTypeDef",
    "StopKeyUsageOutputTypeDef",
    "TagResourceInputRequestTypeDef",
    "TagTypeDef",
    "TrustedCertificatePublicKeyTypeDef",
    "UntagResourceInputRequestTypeDef",
    "UpdateAliasInputRequestTypeDef",
    "UpdateAliasOutputTypeDef",
    "WrappedKeyTypeDef",
)


class AliasTypeDef(TypedDict):
    AliasName: str
    KeyArn: NotRequired[str]


class CreateAliasInputRequestTypeDef(TypedDict):
    AliasName: str
    KeyArn: NotRequired[str]


class ResponseMetadataTypeDef(TypedDict):
    RequestId: str
    HTTPStatusCode: int
    HTTPHeaders: dict[str, str]
    RetryAttempts: int
    HostId: NotRequired[str]


class TagTypeDef(TypedDict):
    Key: str
    Value: str


class DeleteAliasInputRequestTypeDef(TypedDict):
    AliasName: str


class DeleteKeyInputRequestTypeDef(TypedDict):
    KeyIdentifier: str
    DeleteKeyInDays: NotRequired[int]


class ExportDukptInitialKeyTypeDef(TypedDict):
    KeySerialNumber: str


class ExportKeyCryptogramTypeDef(TypedDict):
    CertificateAuthorityPublicKeyIdentifier: str
    WrappingKeyCertificate: str
    WrappingSpec: NotRequired[WrappingKeySpecType]


class WrappedKeyTypeDef(TypedDict):
    WrappingKeyArn: str
    WrappedKeyMaterialFormat: WrappedKeyMaterialFormatType
    KeyMaterial: str
    KeyCheckValue: NotRequired[str]
    KeyCheckValueAlgorithm: NotRequired[KeyCheckValueAlgorithmType]


class GetAliasInputRequestTypeDef(TypedDict):
    AliasName: str


class GetKeyInputRequestTypeDef(TypedDict):
    KeyIdentifier: str


class GetParametersForExportInputRequestTypeDef(TypedDict):
    KeyMaterialType: KeyMaterialTypeType
    SigningKeyAlgorithm: KeyAlgorithmType


class GetParametersForImportInputRequestTypeDef(TypedDict):
    KeyMaterialType: KeyMaterialTypeType
    WrappingKeyAlgorithm: KeyAlgorithmType


class GetPublicKeyCertificateInputRequestTypeDef(TypedDict):
    KeyIdentifier: str


class ImportTr31KeyBlockTypeDef(TypedDict):
    WrappingKeyIdentifier: str
    WrappedKeyBlock: str


class ImportTr34KeyBlockTypeDef(TypedDict):
    CertificateAuthorityPublicKeyIdentifier: str
    SigningKeyCertificate: str
    ImportToken: str
    WrappedKeyBlock: str
    KeyBlockFormat: Literal["X9_TR34_2012"]
    RandomNonce: NotRequired[str]


class KeyModesOfUseTypeDef(TypedDict):
    Encrypt: NotRequired[bool]
    Decrypt: NotRequired[bool]
    Wrap: NotRequired[bool]
    Unwrap: NotRequired[bool]
    Generate: NotRequired[bool]
    Sign: NotRequired[bool]
    Verify: NotRequired[bool]
    DeriveKey: NotRequired[bool]
    NoRestrictions: NotRequired[bool]


class PaginatorConfigTypeDef(TypedDict):
    MaxItems: NotRequired[int]
    PageSize: NotRequired[int]
    StartingToken: NotRequired[str]


class ListAliasesInputRequestTypeDef(TypedDict):
    KeyArn: NotRequired[str]
    NextToken: NotRequired[str]
    MaxResults: NotRequired[int]


class ListKeysInputRequestTypeDef(TypedDict):
    KeyState: NotRequired[KeyStateType]
    NextToken: NotRequired[str]
    MaxResults: NotRequired[int]


class ListTagsForResourceInputRequestTypeDef(TypedDict):
    ResourceArn: str
    NextToken: NotRequired[str]
    MaxResults: NotRequired[int]


class RestoreKeyInputRequestTypeDef(TypedDict):
    KeyIdentifier: str


class StartKeyUsageInputRequestTypeDef(TypedDict):
    KeyIdentifier: str


class StopKeyUsageInputRequestTypeDef(TypedDict):
    KeyIdentifier: str


class UntagResourceInputRequestTypeDef(TypedDict):
    ResourceArn: str
    TagKeys: Sequence[str]


class UpdateAliasInputRequestTypeDef(TypedDict):
    AliasName: str
    KeyArn: NotRequired[str]


class CreateAliasOutputTypeDef(TypedDict):
    Alias: AliasTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class GetAliasOutputTypeDef(TypedDict):
    Alias: AliasTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class GetParametersForExportOutputTypeDef(TypedDict):
    SigningKeyCertificate: str
    SigningKeyCertificateChain: str
    SigningKeyAlgorithm: KeyAlgorithmType
    ExportToken: str
    ParametersValidUntilTimestamp: datetime
    ResponseMetadata: ResponseMetadataTypeDef


class GetParametersForImportOutputTypeDef(TypedDict):
    WrappingKeyCertificate: str
    WrappingKeyCertificateChain: str
    WrappingKeyAlgorithm: KeyAlgorithmType
    ImportToken: str
    ParametersValidUntilTimestamp: datetime
    ResponseMetadata: ResponseMetadataTypeDef


class GetPublicKeyCertificateOutputTypeDef(TypedDict):
    KeyCertificate: str
    KeyCertificateChain: str
    ResponseMetadata: ResponseMetadataTypeDef


class ListAliasesOutputTypeDef(TypedDict):
    Aliases: list[AliasTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class UpdateAliasOutputTypeDef(TypedDict):
    Alias: AliasTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class ListTagsForResourceOutputTypeDef(TypedDict):
    Tags: list[TagTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class TagResourceInputRequestTypeDef(TypedDict):
    ResourceArn: str
    Tags: Sequence[TagTypeDef]


class ExportAttributesTypeDef(TypedDict):
    ExportDukptInitialKey: NotRequired[ExportDukptInitialKeyTypeDef]
    KeyCheckValueAlgorithm: NotRequired[KeyCheckValueAlgorithmType]


class ExportKeyOutputTypeDef(TypedDict):
    WrappedKey: WrappedKeyTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class KeyAttributesTypeDef(TypedDict):
    KeyUsage: KeyUsageType
    KeyClass: KeyClassType
    KeyAlgorithm: KeyAlgorithmType
    KeyModesOfUse: KeyModesOfUseTypeDef


class KeyBlockHeadersTypeDef(TypedDict):
    KeyModesOfUse: NotRequired[KeyModesOfUseTypeDef]
    KeyExportability: NotRequired[KeyExportabilityType]
    KeyVersion: NotRequired[str]
    OptionalBlocks: NotRequired[Mapping[str, str]]


class ListAliasesInputPaginateTypeDef(TypedDict):
    KeyArn: NotRequired[str]
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]


class ListKeysInputPaginateTypeDef(TypedDict):
    KeyState: NotRequired[KeyStateType]
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]


class ListTagsForResourceInputPaginateTypeDef(TypedDict):
    ResourceArn: str
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]


class CreateKeyInputRequestTypeDef(TypedDict):
    KeyAttributes: KeyAttributesTypeDef
    Exportable: bool
    KeyCheckValueAlgorithm: NotRequired[KeyCheckValueAlgorithmType]
    Enabled: NotRequired[bool]
    Tags: NotRequired[Sequence[TagTypeDef]]


class ImportKeyCryptogramTypeDef(TypedDict):
    KeyAttributes: KeyAttributesTypeDef
    Exportable: bool
    WrappedKeyCryptogram: str
    ImportToken: str
    WrappingSpec: NotRequired[WrappingKeySpecType]


class KeySummaryTypeDef(TypedDict):
    KeyArn: str
    KeyState: KeyStateType
    KeyAttributes: KeyAttributesTypeDef
    KeyCheckValue: str
    Exportable: bool
    Enabled: bool


class KeyTypeDef(TypedDict):
    KeyArn: str
    KeyAttributes: KeyAttributesTypeDef
    KeyCheckValue: str
    KeyCheckValueAlgorithm: KeyCheckValueAlgorithmType
    Enabled: bool
    Exportable: bool
    KeyState: KeyStateType
    KeyOrigin: KeyOriginType
    CreateTimestamp: datetime
    UsageStartTimestamp: NotRequired[datetime]
    UsageStopTimestamp: NotRequired[datetime]
    DeletePendingTimestamp: NotRequired[datetime]
    DeleteTimestamp: NotRequired[datetime]


class RootCertificatePublicKeyTypeDef(TypedDict):
    KeyAttributes: KeyAttributesTypeDef
    PublicKeyCertificate: str


class TrustedCertificatePublicKeyTypeDef(TypedDict):
    KeyAttributes: KeyAttributesTypeDef
    PublicKeyCertificate: str
    CertificateAuthorityPublicKeyIdentifier: str


class ExportTr31KeyBlockTypeDef(TypedDict):
    WrappingKeyIdentifier: str
    KeyBlockHeaders: NotRequired[KeyBlockHeadersTypeDef]


class ExportTr34KeyBlockTypeDef(TypedDict):
    CertificateAuthorityPublicKeyIdentifier: str
    WrappingKeyCertificate: str
    ExportToken: str
    KeyBlockFormat: Literal["X9_TR34_2012"]
    RandomNonce: NotRequired[str]
    KeyBlockHeaders: NotRequired[KeyBlockHeadersTypeDef]


class ListKeysOutputTypeDef(TypedDict):
    Keys: list[KeySummaryTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class CreateKeyOutputTypeDef(TypedDict):
    Key: KeyTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class DeleteKeyOutputTypeDef(TypedDict):
    Key: KeyTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class GetKeyOutputTypeDef(TypedDict):
    Key: KeyTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class ImportKeyOutputTypeDef(TypedDict):
    Key: KeyTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class RestoreKeyOutputTypeDef(TypedDict):
    Key: KeyTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class StartKeyUsageOutputTypeDef(TypedDict):
    Key: KeyTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class StopKeyUsageOutputTypeDef(TypedDict):
    Key: KeyTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class ImportKeyMaterialTypeDef(TypedDict):
    RootCertificatePublicKey: NotRequired[RootCertificatePublicKeyTypeDef]
    TrustedCertificatePublicKey: NotRequired[TrustedCertificatePublicKeyTypeDef]
    Tr31KeyBlock: NotRequired[ImportTr31KeyBlockTypeDef]
    Tr34KeyBlock: NotRequired[ImportTr34KeyBlockTypeDef]
    KeyCryptogram: NotRequired[ImportKeyCryptogramTypeDef]


class ExportKeyMaterialTypeDef(TypedDict):
    Tr31KeyBlock: NotRequired[ExportTr31KeyBlockTypeDef]
    Tr34KeyBlock: NotRequired[ExportTr34KeyBlockTypeDef]
    KeyCryptogram: NotRequired[ExportKeyCryptogramTypeDef]


class ImportKeyInputRequestTypeDef(TypedDict):
    KeyMaterial: ImportKeyMaterialTypeDef
    KeyCheckValueAlgorithm: NotRequired[KeyCheckValueAlgorithmType]
    Enabled: NotRequired[bool]
    Tags: NotRequired[Sequence[TagTypeDef]]


class ExportKeyInputRequestTypeDef(TypedDict):
    KeyMaterial: ExportKeyMaterialTypeDef
    ExportKeyIdentifier: str
    ExportAttributes: NotRequired[ExportAttributesTypeDef]
